This program contains the stuff necessary for implementing logic gates in Python 3.4 and above.

I have implemented everything on top of the universal gate NAND

This module currently can execute the following logic gates:

1. NAND gate
2. AND gate
3. OR gate
4. NOR gate
5. NOT gate
6. XOR gate
7. XNOR gate
8. Half adder
9. Full Adder
10. Ripple Carry Adder
11. Half subtractor
12. Subtractor
13. AND gate with 3 inputs
14. OR gate with multiple inputs

I hope this module proved to be of use for you.

If you have suggestions or find any bugs, please let me know.

Contact me at: nbalaji.buisness@gmail.com